@@ -6,20 +6,24 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-__version__ = "0.0.11"
+__version__ = "0.0.13"
 
 from .broker import (
     MinosBaseBroker,
 )
 from .configuration import (
     BROKER,
-    COMMAND,
     COMMANDS,
+    CONTROLLER,
     ENDPOINT,
-    EVENT,
     EVENTS,
+    QUEUE,
+    REPOSITORY,
     REST,
+    SAGA,
     SERVICE,
+    SNAPSHOT,
+    STORAGE,
     MinosConfig,
     MinosConfigAbstract,
 )
@@ -117,6 +121,9 @@ from .repository import (
     MinosRepositoryEntry,
     PostgreSqlMinosRepository,
 )
+from .saga import (
+    MinosSagaManager,
+)
 from .setup import (
     MinosSetup,
 )
